@@ -29,4 +29,7 @@ type TracingOperator interface {
 	CaptureContext() interface{}
 	ContinueContext(interface{})
 	CleanContext()
+
+	GetCorrelationContextValue(key string) string
+	SetCorrelationContextValue(key, val string)
 }
