@@ -54,10 +54,11 @@ type Tracer struct {
 	meterMap              *sync.Map
 	meterCollectListeners []func()
 	ignoreSuffix          []string
+	traceIgnorePath       []string
 }
 
 func (t *Tracer) Init(entity *reporter.Entity, rep reporter.Reporter, samp Sampler, logger operator.LogOperator,
-	meterCollectSecond int, correlation *CorrelationConfig, ignoreSuffixStr string) error {
+	meterCollectSecond int, correlation *CorrelationConfig, ignoreSuffixStr string, ignorePath string) error {
 	t.ServiceEntity = entity
 	t.Reporter = rep
 	t.Sampler = samp
@@ -69,6 +70,7 @@ func (t *Tracer) Init(entity *reporter.Entity, rep reporter.Reporter, samp Sampl
 	t.initMetricsCollect(meterCollectSecond)
 	t.correlation = correlation
 	t.ignoreSuffix = strings.Split(ignoreSuffixStr, ",")
+	t.traceIgnorePath = strings.Split(ignorePath, ",")
 	// notify the tracer been init success
 	if len(GetInitNotify()) > 0 {
 		for _, fun := range GetInitNotify() {
