@@ -18,10 +18,12 @@
 package agentcore
 
 import (
+	"fmt"
 	"html"
 	"io/fs"
 	"path/filepath"
 	"regexp"
+	"runtime"
 	"strings"
 
 	"github.com/apache/skywalking-go/plugins/core"
@@ -66,7 +68,21 @@ func (i *Instrument) FilterAndEdit(path string, curFile *dst.File, cursor *dstut
 	}
 	targetDir := filepath.Dir(path)
 	for _, sub := range CopiedSubPackages {
-		if regexp.MustCompile(filepath.Join(CopiedBasePackage, sub) + "$").MatchString(targetDir) {
+		// On os=windows, we need to escape the characters,
+		// and we can't just use "filepath.Join",
+		// which would cause the regex to throw an error
+		var prefix string
+		if runtime.GOOS == "windows" {
+			prefix = strings.ReplaceAll(CopiedBasePackage, `\/`, `\\`)
+			if sub != "" {
+				prefix = fmt.Sprintf(`%s\\%s`, prefix, sub)
+			}
+		} else {
+			prefix = filepath.Join(CopiedBasePackage, sub)
+		}
+
+		res := prefix + "$"
+		if regexp.MustCompile(res).MatchString(targetDir) {
 			i.needsCopyDir = sub
 			i.hasCopyPath = true
 			return true
@@ -94,6 +110,14 @@ func (i *Instrument) WriteExtraFiles(dir string) ([]string, error) {
 		pkgUpdates[filepath.Join(EnhanceFromBasePackage, p)] = filepath.Join(EnhanceBasePackage, p)
 	}
 	pkgUpdates[filepath.Join(EnhanceFromBasePackage, ReporterFromBasePackage)] = filepath.Join(ProjectBasePackage, ReporterBasePackage)
+
+	for k, v := range pkgUpdates {
+		newKey := strings.ReplaceAll(k, `\`, `/`)
+		newVal := strings.ReplaceAll(v, `\`, `/`)
+
+		pkgUpdates[newKey] = newVal
+	}
+
 	copiedFiles, err := tools.CopyGoFiles(core.FS, sub, dir, i.buildDSTDebugInfo, func(file *dst.File) {
 		tools.ChangePackageImportPath(file, pkgUpdates)
 	})
@@ -163,7 +187,8 @@ func (t *Tracer) InitTracer(extend map[string]interface{}) {
 		MaxValueSize : {{.Config.Agent.Correlation.MaxValueSize.ToGoIntValue "loading the agent correlation maxValueSize error"}},
 	}
 	ignoreSuffixStr := {{.Config.Agent.IgnoreSuffix.ToGoStringValue}}
-	if err := t.Init(entity, rep, samp, logger, meterCollectInterval, correlation, ignoreSuffixStr); err != nil {
+	ignorePath := {{.Config.Agent.TraceIgnorePath.ToGoStringValue}}
+	if err := t.Init(entity, rep, samp, logger, meterCollectInterval, correlation, ignoreSuffixStr, ignorePath); err != nil {
 		t.Log.Errorf("cannot initialize the SkyWalking Tracer: %v", err)
 	}
 }`, struct {
